@@ -44,11 +44,11 @@ def get_packages(api_root, org_id):
     return "{api_root}/{org_id}/packages/".format(**locals())
 
 
-def post_release(api_root, org_id, release_id):
+def post_release(api_root, org_id, package_id):
     return "{api_root}/{org_id}/packages/{package_id}/releases/".format(**locals())
 
 
-def get_release_status(api_root, org_id, release_id, timestamp):
+def get_release_status(api_root, org_id, package_id, release_id, timestamp):
     return "{api_root}/{org_id}/packages/{package_id}/releases/{release_id}?_={timestamp}".format(**locals())
 
 
@@ -112,9 +112,17 @@ def view_run(api_root, org_id, project_id, run_id):
     return "{api_root}/{org_id}/{project_id}/runs/{run_id}.embed".format(**locals())
 
 
+def view_instruction(api_root, org_id, project_id, run_id, instruction_id):
+    return "{api_root}/{org_id}/{project_id}/runs/{run_id}/instructions/{instruction_id}.embed".format(**locals())
+
+
 def view_raw_image(api_root, data_id):
     return "{api_root}/-/{data_id}.raw".format(**locals())
 
 
+def get_data_zip(api_root, data_id):
+    return "{api_root}/-/{data_id}.zip".format(**locals())
+
+
 def monitoring_data(api_root, org_id, project_id, run_id, instruction_id, data_type):
     return "{api_root}/{org_id}/{project_id}/runs/{run_id}/{instruction_id}/monitoring/{data_type}".format(**locals())
